# masnel-pyqt

This project is a wrapper for the [mansel](https://github.com/willsALMANJ/mansel) project using PyQt5.
It can be installed via

    pip install mansel-pyqt

to install `mansel` with binding to `PyQt5`.
`mansel-pyqt` is packaged separately from `mansel` to comply with the `PyQt5` license.
Refer to the `mansel` documentation for usage information.
